const inquirer = require('inquirer');
const { QUESTIONS, OPTIONS } = require('../constants');

module.exports = {
  askServerQuestions: () => {
    const questions = [
      {
        name: 'appName',
        type: 'input',
        message: QUESTIONS.APP_NAME,
        validate: function (value) {
          if (value.length) {
            return true;
          } else {
            return QUESTIONS.VALIDATIONS.APP_NAME;
          }
        },
      },
      {
        name: 'folderName',
        type: 'input',
        message: QUESTIONS.FOLDER,
        validate: function (value) {
          if (value.length) {
            return true;
          } else {
            return QUESTIONS.VALIDATIONS.FOLDER;
          }
        },
      },
      {
        name: 'cloudProvider',
        type: 'list',
        message: QUESTIONS.CLOUD_PROVIDER,
        choices: [
          OPTIONS.CLOUD_PROVIDERS.AWS,
          OPTIONS.CLOUD_PROVIDERS.AZURE,
          OPTIONS.CLOUD_PROVIDERS.GCP,
        ],
        default: OPTIONS.CLOUD_PROVIDERS.AWS,
      },
      {
        name: 'credentials',
        type: 'input',
        message: QUESTIONS.CLOUD_PROVIDER_CREDENTIALS,
        validate: function (value) {
          if (value.length) {
            return true;
          } else {
            return QUESTIONS.VALIDATIONS.CREDENTIALS;
          }
        },
      },
      {
        name: 'openAi',
        type: 'list',
        message: QUESTIONS.OPENAI,
        choices: [OPTIONS.CONFIRMATION.YES, OPTIONS.CONFIRMATION.NO],
        default: OPTIONS.CONFIRMATION.YES,
      },
    ];
    return inquirer.prompt(questions);
  },
  confirm: () => {
    const questions = [
      {
        name: 'response',
        type: 'list',
        message: QUESTIONS.CONTINUE,
        choices: [
          { name: OPTIONS.CONFIRMATION.YES, value: true },
          { name: OPTIONS.CONFIRMATION.NO, value: false },
        ],
        default: OPTIONS.CONFIRMATION.YES,
      },
    ];
    return inquirer.prompt(questions);
  },
};
